summaryrefslogtreecommitdiff
path: root/mpn/pa64/submul_1.S
diff options
context:
space:
mode:
Diffstat (limited to 'mpn/pa64/submul_1.S')
-rw-r--r--mpn/pa64/submul_1.S6
1 files changed, 3 insertions, 3 deletions
diff --git a/mpn/pa64/submul_1.S b/mpn/pa64/submul_1.S
index bf875eedc..2a9402f22 100644
--- a/mpn/pa64/submul_1.S
+++ b/mpn/pa64/submul_1.S
@@ -1,4 +1,4 @@
; HP-PA 2.0 64-bit __mpn_submul_1 -- Multiply a limb vector with a limb and
; subtract the result from a second limb vector.
; Copyright (C) 1998, 1999 Free Software Foundation, Inc.
@@ -43,8 +43,8 @@
#define t4 %r31
.level 2.0n
.code
- .export __mpn_submul_1
-__mpn_submul_1
+ .export __gmpn_submul_1
+__gmpn_submul_1
.proc
.callinfo frame=128,no_calls
.entry
@@ -1,4 +1,4 @@
-; HP-PA 2.0 64-bit __mpn_submul_1 -- Multiply a limb vector with a limb and
+; HP-PA 2.0 64-bit __gmpn_submul_1 -- Multiply a limb vector with a limb and
; subtract the result from a second limb vector.
; Copyright (C) 1998, 1999 Free Software Foundation, Inc.